Keeper Commander Incorporates FIDO U2F Security Keys
----

As a part of Keeper’s core offering, FIDO U2F and YubiKey support will now be available to our individual users and enterprise accounts. With our mission to make the internet secure for everyone we are thrilled to partner with these world class companies to deliver the highest level of security to our customers. The feature is immediately available to all Keeper customers and provides the added protection and security of hardware 2FA for their critical accounts.

To use FIDO U2F Security Keys with Keeper Commander:
1. Setup your account to use Security Key with Keeper Vault https://keepersecurity.com/vault.
2. Install **fido2** python module module
```bash
pip3 install fido2
```
